# djangolint
[![Build Status](https://travis-ci.org/tangwz/djangolint.svg?branch=master)](https://travis-ci.org/tangwz/djangolint)
[![Coverage Status](https://coveralls.io/repos/github/hcgop/djangolint/badge.svg?branch=master&service=github)](https://coveralls.io/github/hcgop/djangolint?branch=master)

A flexible json validation for python web development.

# Installation
Install or upgrade using pip.

    pip install djangolint

Install from source:

    python setup.py install


# Links
 - [Documentation](http://djangolint.readthedocs.io/)
 - [PyPi](https://pypi.python.org/pypi/djangolint/0.1)
 - [Github](https://github.com/hcgop/djangolint.git)
 
# To-do
 - Generating interactive documentation (with Swagger UI)

# Third-Party Library Integrations
- [Flask-Lint](https://github.com/tangwz/Flask-Lint) is an integration with the Flask framework.
- [DjangoLint](https://github.com/hcgop/djangolint.git) forked by [JsonLint](https://github.com/tangwz/jsonlint.git) is an integration with the Flask framework.

# Reference
djangolint built on [wtforms](https://github.com/wtforms/wtforms).
